@@ -20,7 +20,7 @@
 /*                                                                        */
 /**************************************************************************/
 
-/* $Id: ml_gobject.c 1369 2007-09-25 02:56:09Z garrigue $ */
+/* $Id: ml_gobject.c 1410 2008-07-25 08:46:42Z oandrieu $ */
 #include <stdio.h>
 #include <glib.h>
 #include <glib-object.h>
@@ -39,19 +39,27 @@
 
 /* gobject.h */
 
-static gboolean ml_g_object_unref0 (gpointer p)
-{ g_object_unref((GObject*)p); return 0; }
+static GQueue objects_to_unref; /* initialized to zeroes (empty queue) */
+
+CAMLprim value ml_g_object_do_unref (value unit)
+{
+  while (! g_queue_is_empty (&objects_to_unref))
+    {
+      gpointer d = g_queue_pop_tail (&objects_to_unref);
+      g_object_unref (G_OBJECT (d));
+    }
+  return Val_unit;
+}
 
 CAMLexport void ml_g_object_unref_later (GObject *p)
 {
-    g_timeout_add_full(G_PRIORITY_HIGH_IDLE, 0, ml_g_object_unref0,
-                       (gpointer)(p), NULL);
+  g_queue_push_head (&objects_to_unref, p);
 }
 
 
 Make_Val_final_pointer(GObject, g_object_ref, ml_g_object_unref_later, 0)
 Make_Val_final_pointer_ext (GObject, _new, Ignore, ml_g_object_unref_later, 20)
-ML_1 (G_TYPE_FROM_INSTANCE, GObject_val, Val_int)
+ML_1 (G_TYPE_FROM_INSTANCE, GObject_val, Val_GType)
 // ML_1 (g_object_ref, GObject_val, Unit)
 CAMLprim value ml_g_object_unref (value val)
 {
